pub struct Thread {
pub parent: Option<String>,
pub id: String,
}Expand description
Threading meta-information.
Fields
parent: Option<String>The parent of the thread, when creating a subthread.
id: StringA thread identifier, so that other people can specify to which message they are replying.